Experiment Exports — Map of Objects

Skip to main content
`Ctrl`+`K`

# Experiment Exports

export_distances_multiple_processes(experiment, instances_ids, distances, times, process_id)

  Exports distances between each pair of instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - instances_ids – List of the Ids.

    - distances (dict) – Dictionary with distances between each pair of instances

    - times (dict) – Dictionary with time of calculation of each distance.

    - process_id (bool) – Id of the process.

export_distances_to_file(experiment, distance_id, distances, times, self_distances=False, ids=None)

  Exports distances between each pair of instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - distance_id (str) – Name of the distance.

    - distances (dict) – Dictionary with distances between each pair of instances

    - times (dict) – Dictionary with time of calculation of each distance.

    - self_distances (bool) – Flag indicating whether to export self-distances.

    - ids – List of the Ids.

export_embedding_to_file(experiment, embedding_id: str, saveas: str, dim: int, my_pos)

  Exports coordinates of all instances to a .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - embedding_id (str) – Name of the embedding.

    - saveas (str) – Name of the file to save the feature to.

    - dim (int) – Dimension of the embedding.

    - my_pos – list of coordinates

export_feature_to_file(experiment, feature_id, feature_dict, saveas)

  Exports feature to .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - feature_id (str) – Name of the feature.

    - feature_dict (dict) – Dictionary with feature values.

    - saveas (str) – Name of the file to save the feature to.

export_normalized_feature_to_file(experiment, feature_dict=None, saveas=None)

  Exports normalized feature to .csv file.

  Parameters:

    - experiment (Experiment) – Experiment object.

    - feature_dict (dict) – Dictionary with feature values.

    - saveas (str) – Name of the file to save the feature to.